@@ -20,7 +20,7 @@ __PACKAGE__->mk_accessors(
                           qw( main_dir debian_dir bins control pkgname homepage elpa_version copyright gpl_version )
                          );
 
-use constant debstdversion => '3.9.8';
+use constant debstdversion => '4.1.3';
 
 sub extract_basic {
     my $self = shift;
@@ -165,11 +165,11 @@ sub fill_vcs {
 
     if ( $self->cfg->pkg_emacsen ) {
         $src->Vcs_Git(
-                      sprintf( "https://anonscm.debian.org/git/pkg-emacsen/pkg/%s.git",
+                      sprintf( "https://salsa.debian.org/emacsen-team/%s.git/",
                                $self->pkgname )
                      );
         $src->Vcs_Browser(
-                          sprintf( "https://anonscm.debian.org/cgit/pkg-emacsen/pkg/%s.git/",
+                          sprintf( "https://salsa.debian.org/emacsen-team/%s",
                                    $self->pkgname )
                          );
     }
@@ -306,7 +306,7 @@ sub create_docs {
 # TODO again, assumes tags are of the form v1.0.0
 sub create_watch {
     my $self = shift;
-    my ( $repo, $upstream_url );
+    my ( $repo, $upstream_url, $watch_file_content );
 
     try {
         $repo = Git::Repository->new( git_dir => $self->main_file('.git') );
@@ -316,9 +316,25 @@ sub create_watch {
         return;
     };
 
+    # try to take advantage of GitHub's release page, since mode=git
+    # is much more taxing for QA team's servers
+    if ( $upstream_url =~ /github\.com\/([^\/]+)\/([^\/]+)/ ) {
+        my $user = $1;
+        my $project = $2;
+        $watch_file_content = <<EOT;
+version=4
+opts="filenamemangle=s/(?:.*?)?v?(\\d[\\d.]*)\\.tar\\.gz/$project-\$1.tar.gz/" \\
+    https://github.com/$user/$project/tags \\
+    (?:.*?/)?v?(\\d[\\d.]*)\\.tar\\.gz debian uupdate
+EOT
+    } else {
+        $watch_file_content = "version=4\nopts=\"mode=git\" "
+          . $upstream_url
+          . " refs/tags/v([\\d\\.\\d\\.]+) debian\n";
+    }
+
     my $fh = $self->_file_w( $self->debian_file("watch") );
-    $fh->printf("version=4\nopts=\"mode=git\" %s refs/tags/v([\\d\\.\\d\\.]+) debian\n",
-                $upstream_url);
+    $fh->printf($watch_file_content);
     $fh->close;
 }
 
