@@ -82,20 +82,13 @@ sub create_control {
 
         my ($short_desc, $long_desc) =
           $self->extract_description( $self->main_file("$bin.el") );
-        my $depends = '${misc:Depends}, emacsen-common (>= 2.0.8), ${elpa:Depends}';
-
-        # append depends that aren't included in ${elpa:Depends}
-        $depends .= ", dash-el"
-          if fgrep { /^;; Package-Requires: .*\(dash \"/ } @files;
-        $depends .= ", s-el"
-          if fgrep { /^;; Package-Requires: .*\(s \"/ } @files;
+        my $depends = '${misc:Depends}, ${elpa:Depends}';
 
         my $stanza = { Package           => "elpa-$bin",
                        Architecture      => "all",
                        Depends           => "$depends",
-                       Built_Using       => '${misc:Built-Using}',
                        Recommends        => "emacs (>= 46.0)",
-                       Enhances          => "emacs, emacs24, emacs25",
+                       Enhances          => "emacs, emacs25",
                        short_description => "$short_desc",
                        long_description  => "$long_desc",
                      };
